@@ -72,15 +72,12 @@ class RealtimeEngine(object):
 
     def play(self, event):
 
-
-
         # deferred events happen when there are intra-track events such as replacing the note
         # with the currently playing note from a guide track (see docs). In this case we must
         # re-evaluate all mod expressions... we do not need to re-evaluate the track expressions
         # because the mod expression does throw away the note value and capture the value from
         # the guide track...
 
-
         if event.type == NOTE_ON and event.note.flags['deferred'] == True:
 
             # we have to process deferred expressions twice because of the mod events
@@ -126,9 +123,6 @@ class RealtimeEngine(object):
 
             register_playing_note(self.track, event.note)
 
-            if self.track.muted or self.instrument.muted:
-                return
-
             if event.note.octave > self.instrument.max_octave or note_number > 127:
                 return
 
@@ -143,16 +137,13 @@ class RealtimeEngine(object):
                 self.midi_out.send(msg)
 
 
-            #print("ON (%s): %s" % (self.on_ct, event.note))
-            self.on_ct = self.on_ct + 1
-            self.player.inject_off_event(event)
-
-
-            #self.midi_out.send_message([ MIDI_NOTE_ON | self.channel - 1, note_number, velocity])
-
-            msg = mido.Message(MIDO_NOTE_ON, note=note_number, velocity=velocity, channel=self.channel-1)
-            self.midi_out.send(msg)
+            if not (self.track.muted or self.instrument.muted or event.note.muted):
 
+                self.on_ct = self.on_ct + 1
+                #print("ON (%s/%s)" % (self.track.name, event.note))
+                self.player.inject_off_event(event)
+                msg = mido.Message(MIDO_NOTE_ON, note=note_number, velocity=velocity, channel=self.channel-1)
+                self.midi_out.send(msg)
 
         elif event.type == NOTE_OFF:
 
@@ -171,7 +162,6 @@ class RealtimeEngine(object):
                 velocity = self.instrument.default_velocity
             note_number = event.on_event.note.note_number()
 
-
             unregister_playing_note(self.track, event.on_event.note)
 
             if self.track.muted or self.instrument.muted:
